@@ -32,11 +32,11 @@ import sipconfig
 
 
 # Initialise the globals.
-pyqt_version = 0x030e01
-pyqt_version_str = "3.14.1"
+pyqt_version = 0x030f01
+pyqt_version_str = "3.15.1"
 
 sip_min_v3_version = 0x030c00
-sip_min_v4_version = 0x040200
+sip_min_v4_version = 0x040300
 
 pyqt_modules = ["qt"]
 qt_sip_flags = []
@@ -70,6 +70,7 @@ opt_split = 1
 opt_releasegil = 0
 opt_tracing = 0
 opt_verbose = 0
+opt_keepfeatures = 0
 
 opt_vendorcheck = 0
 opt_vendincdir = sipcfg.py_inc_dir
@@ -82,13 +83,14 @@ def usage(rcode = 2):
     rcode is the return code passed back to the calling process.
     """
     print "Usage:"
-    print "    python configure.py [-h] [-a tag] [-b dir] [-c] [-d dir] [-i] [-j #] [-k] [-l dir] [-m dir] [-n dir] [-o dir] [-r] [-s] [-u] [-v dir] [-w]"
+    print "    python configure.py [-h] [-a tag] [-b dir] [-c] [-d dir] [-f] [-i] [-j #] [-k] [-l dir] [-m dir] [-n dir] [-o dir] [-r] [-s] [-u] [-v dir] [-w]"
     print "where:"
     print "    -h      display this help message"
     print "    -a tag  explicitly enable the qtpe module"
     print "    -b dir  where pyuic and pylupdate will be installed [default %s]" % opt_pyqtbindir
     print "    -c      concatenate each module's C/C++ source files"
     print "    -d dir  where the PyQt modules will be installed [default %s]" % opt_pyqtmoddir
+    print "    -f      keep any existing features file (when cross-compiling) [default remove]"
     print "    -i      enable checking of signed interpreters using the VendorID package [default disabled]"
     print "    -j #    split the concatenated C++ source files into # pieces [default 1]"
     print "    -k      build the PyQt modules as static libraries"
@@ -464,7 +466,7 @@ def get_feature_flags():
     featfile = "features"
 
     # Create the features file if it doesn't exist.
-    if os.access(featfile,os.F_OK):
+    if opt_keepfeatures and os.access(featfile,os.F_OK):
         sipconfig.inform("Using existing features file.")
     else:
         sipconfig.inform("Creating features file...")
@@ -526,7 +528,8 @@ def set_sip_flags():
         0x030102: "Qt_3_1_1",
         0x030200: "Qt_3_1_2",
         0x030300: "Qt_3_2_0",
-        0x040000: "Qt_3_3_0"
+        0x030305: "Qt_3_3_0",
+        0x040000: "Qt_3_3_5"
     }
 
     qt_sip_flags.append("-t")
@@ -545,7 +548,8 @@ def set_sip_flags():
             0x010300: "QScintilla_1_2",
             0x010400: "QScintilla_1_3",
             0x010500: "QScintilla_1_4",
-            0x020000: "QScintilla_1_5"
+            0x010600: "QScintilla_1_5",
+            0x020000: "QScintilla_1_6"
         }
 
         qtext_sip_flags.append("-t")
@@ -858,13 +862,13 @@ def main(argv):
     argv is the list of command line arguments.
     """
     try:
-        optlist, args = getopt.getopt(argv[1:], "ha:b:cd:gij:kl:m:n:o:rsuv:w")
+        optlist, args = getopt.getopt(argv[1:], "ha:b:cd:fgij:kl:m:n:o:rsuv:w")
     except getopt.GetoptError:
         usage()
 
     global opt_pyqtbindir, opt_pyqtmoddir, opt_pyqtsipdir
     global opt_qtpetag, opt_static, opt_debug, opt_concat, opt_releasegil
-    global opt_split, opt_tracing, opt_verbose
+    global opt_split, opt_tracing, opt_verbose, opt_keepfeatures
     global opt_qsciincdir, opt_qscilibdir, qsci_define
     global opt_vendorcheck, opt_vendincdir, opt_vendlibdir
 
@@ -879,6 +883,8 @@ def main(argv):
             opt_concat = 1
         elif opt == "-d":
             opt_pyqtmoddir = os.path.abspath(arg)
+        elif opt == "-f":
+            opt_keepfeatures = 1
         elif opt == "-g":
             opt_releasegil = 1
         elif opt == "-i":
@@ -933,7 +939,7 @@ def main(argv):
                 minv = sip_min_v3_version
 
         if minv:
-            sipcfg.error("This version of PyQt requires SIP v%s or later" % sipcfg.version_to_string(minv))
+            sipconfig.error("This version of PyQt requires SIP v%s or later" % sipconfig.version_to_string(minv))
 
     # Check for QScintilla.
     check_qscintilla()
